---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '...'
3. Type '...'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**System (please complete the following information, either manually or just paste the output of given commands):**
 - OS and version: [e.g. Ubuntu 20.04]
`lsb_release -a` or `cat /etc/*-release`
- Terminal [e.g. Terminator]
`$(ps -p $(ps -p $$ -o ppid=) o args=) --version`
- Shell [e.g. Bash]
`ps -p $$`
- TERM environment variable
`echo $TERM`

**Additional context**
Add any other context about the problem here.
